@@ -1,6 +1,8 @@
-#' @title Get the Anaytics data from Real Time Reporting API for a view (profile)
+#' @title Real Time Reporting API
 #'
-#' @param profile.id integer or character. Unique table ID for retrieving Analytics data. Table ID is of the form ga:XXXX, where XXXX is the Analytics view (profile) ID. Can be obtained using the \code{\link{list_profiles}} or via the web interface Google Analytics.
+#' @description Get the Anaytics data from Real Time Reporting API for a view (profile).
+#'
+#' @param profile.id character. Unique table ID for retrieving Analytics data. Table ID is of the form ga:XXXX, where XXXX is the Analytics view (profile) ID. Can be obtained using the \code{\link{list_profiles}} or via the web interface Google Analytics.
 #' @param metrics character. A comma-separated list of real time metrics. E.g., \code{"rt:activeUsers"}. At least one metric must be specified.
 #' @param dimensions character. A comma-separated list of real time dimensions. E.g., \code{"rt:medium,rt:city"}.
 #' @param sort character. A comma-separated list of dimensions or metrics that determine the sort order for real time data.
@@ -33,13 +35,9 @@
 #' }
 #'
 #' @include report.R
-#'
-#' @aliases get_rt
-#'
 #' @export
-#'
-get_realtime <- function(profile.id, metrics = "rt:activeUsers", dimensions = NULL,
-                   sort = NULL, filters = NULL, max.results = NULL, token) {
+get_realtime <- function(profile.id = NULL, metrics = "rt:activeUsers", dimensions = NULL,
+                         sort = NULL, filters = NULL, max.results = NULL, token) {
     query <- build_query(profile.id = profile.id, metrics = metrics, dimensions = dimensions,
                          sort = sort, filters = filters, max.results = max.results)
     res <- get_report("data/realtime", query, token)
